==> haskell-checkers-0.6.0-217-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-1kl1Jq8nNA6Iazr6i17K8H
key:                  checkers-0.6.0-1kl1Jq8nNA6Iazr6i17K8H
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  3299cd2fb414ea542ba28f4a3c89b035
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-1kl1Jq8nNA6Iazr6i17K8H
depends:
    QuickCheck-2.14.3-9HL6RJfCtmHAzoR71QI1Po array-0.5.4.0
    base-4.17.2.1 random-1.2.1.3-7z4mPLTBPidE9rbVioKqnW
    semigroupoids-6.0.1-LFg6aYEwovR32RQPJzssoz

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.6.0-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-HP9hXcBCiCCDc5eYjkIkgn
key:                  checkers-0.6.0-HP9hXcBCiCCDc5eYjkIkgn
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  982ef5bc4661f66f5877766acd9cb608
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-HP9hXcBCiCCDc5eYjkIkgn
depends:
    QuickCheck-2.14.3-J45WF0Yux319EMk6f3cLwH array-0.5.4.0
    base-4.17.2.1 random-1.2.1.3-BJci0ZIHWY7JJvOpU5NHzK
    semigroupoids-6.0.1-Dyiulc79AG72hQ04hyBGLr

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
